<?php
/***************************************************************
*  Copyright notice
*
*  (c) 2009 Ingo Renner <ingo@typo3.org>
*  All rights reserved
*
*  This script is part of the TYPO3 project. The TYPO3 project is
*  free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  The GNU General Public License can be found at
*  http://www.gnu.org/copyleft/gpl.html.
*
*  This script is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  This copyright notice MUST APPEAR in all copies of the script!
***************************************************************/

require_once('phing/Task.php');
require('../../../../t3lib/class.t3lib_div.php');
require('../../../../t3lib/class.t3lib_spritegenerator.php');

/**
 * A phing task to generate css sprites.
 *
 * @author	Ingo Renner <ingo@typo3.org>
 * @package TYPO3
 * @subpackage skin
 */
class tx_skin_spritegenerator_tasks_GenerateSpriteTask extends Task {

	protected $spriteName;
	protected $backgroundImageClassName;
	protected $backgroundImagePath;
	protected $cssClassPrefix;
	protected $cssClassNamePrefix;
	protected $spriteImageDestinationDirectory;
	protected $spriteCssDestinationDirectory;

	protected $filesets = array(); // all fileset objects assigned to this task

	/**
	 * Setter for the sprite name attribute.
	 *
	 * @param	string	the sprite's name
	 */
	public function setName($spriteName) {
		$this->spriteName = $spriteName;
	}

	/**
	 * Setter for the background image class name.
	 *
	 * @param	string	the sprite's name
	 */
	public function setBackgroundImageClassName($backgroundImageClassName) {
		$this->backgroundImageClassName = $backgroundImageClassName;
	}

	/**
	 * Setter for the background image path.
	 *
	 * @param	string	the background image's path
	 */
	public function setBackgroundImagePath($backgroundImagePath) {
		$this->backgroundImagePath = $backgroundImagePath;
	}

	/**
	 * Setter for the optional css class prefix attribute.
	 *
	 * @param	string	A css class prefix
	 */
	public function setCssClassPrefix($cssClassPrefix) {
		$this->cssClassPrefix = $cssClassPrefix;
	}

	/**
	 * Setter for the optional css class name prefix attribute.
	 *
	 * @param	string	A css class name prefix
	 */
	public function setCssClassNamePrefix($cssClassNamePrefix) {
		$this->cssClassNamePrefix = $cssClassNamePrefix;
	}


	public function setImageDestinationDirectory($imageDestinationDirectory) {
		$this->spriteImageDestinationDirectory = $imageDestinationDirectory;
	}

	public function setCssDestinationDirectory($cssDestinationDirectory) {
		$this->spriteCssDestinationDirectory = $cssDestinationDirectory;
	}

	/**
	 * Nested creator, creates a FileSet for this task
	 *
	 * @access  public
	 * @return  object  The created fileset object
	 */
	function createFileSet() {
		$num = array_push($this->filesets, new FileSet());
		return $this->filesets[$num - 1];
	}

	/**
	 * The init method: Do init steps.
	 */
	public function init() {
			// nothing to do here
	}

	/**
	 * The main entry point method.
	 */
	public function main() {
		$project = $this->getProject();
		$workingDirectory = $project->getBasedir()->getAbsolutePath();

		$spriteGenerator = t3lib_div::makeInstance('t3lib_SpriteGenerator',
			$this->spriteName,
			$this->spriteImageDestinationDirectory,
			$this->spriteCssDestinationDirectory,
			$workingDirectory . '/'
		);
		$spriteGenerator->setBackgroundImageClassName($this->backgroundImageClassName);
		$spriteGenerator->setBackgroundImagePath($this->backgroundImagePath);
		$spriteGenerator->setCssClassPrefix($this->cssClassPrefix);
		$spriteGenerator->setCssClassNamePrefix($this->cssClassNamePrefix);

			// process filesets
		foreach($this->filesets as $fs) {
			$ds = $fs->getDirectoryScanner($project);
			$fromDir  = $fs->getDir($project)->getAbsolutePath();
			$srcFiles = $ds->getIncludedFiles();

			foreach ($srcFiles as $srcFile) {
				$spriteGenerator->addImage($fromDir . '/' . $srcFile);
			}
		}

		$spriteGenerator->generateSprite();

		$this->log("Created sprite: " . $this->spriteName);
	}
}


if (defined('TYPO3_MODE') && $TYPO3_CONF_VARS[TYPO3_MODE]['XCLASS']['ext/skin/spritegenerator/tasks/GenerateSpriteTask.php'])	{
	include_once($TYPO3_CONF_VARS[TYPO3_MODE]['XCLASS']['ext/skin/spritegenerator/tasks/GenerateSpriteTask.php']);
}

?>